# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from scalekit.v1.emails import emails_pb2 as scalekit_dot_v1_dot_emails_dot_emails__pb2


class EmailServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetTemplatePlaceholders = channel.unary_unary(
                '/scalekit.v1.emails.EmailService/GetTemplatePlaceholders',
                request_serializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.GetPlaceholdersRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.GetPlaceholdersResponse.FromString,
                )
        self.GetTemplateUseCases = channel.unary_unary(
                '/scalekit.v1.emails.EmailService/GetTemplateUseCases',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.GetTemplateUseCasesResponse.FromString,
                )
        self.CreateEmailTemplate = channel.unary_unary(
                '/scalekit.v1.emails.EmailService/CreateEmailTemplate',
                request_serializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.CreateEmailTemplateRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.CreateEmailTemplateResponse.FromString,
                )
        self.UpdateEmailTemplate = channel.unary_unary(
                '/scalekit.v1.emails.EmailService/UpdateEmailTemplate',
                request_serializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.PatchEmailTemplateRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.GetEmailTemplateResponse.FromString,
                )
        self.GetEmailConfiguration = channel.unary_unary(
                '/scalekit.v1.emails.EmailService/GetEmailConfiguration',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.GetEmailConfigurationResponse.FromString,
                )
        self.UpsertEmailConfiguration = channel.unary_unary(
                '/scalekit.v1.emails.EmailService/UpsertEmailConfiguration',
                request_serializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.UpsertEmailConfigurationRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.UpsertEmailConfigurationResponse.FromString,
                )
        self.EnableEmailTemplate = channel.unary_unary(
                '/scalekit.v1.emails.EmailService/EnableEmailTemplate',
                request_serializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.EnableEmailTemplateRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.EnableEmailTemplateResponse.FromString,
                )
        self.DisableEmailTemplate = channel.unary_unary(
                '/scalekit.v1.emails.EmailService/DisableEmailTemplate',
                request_serializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.DisableEmailTemplateRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetEmailTemplate = channel.unary_unary(
                '/scalekit.v1.emails.EmailService/GetEmailTemplate',
                request_serializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.GetEmailTemplateRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.GetEmailTemplateResponse.FromString,
                )
        self.ListEmailTemplates = channel.unary_unary(
                '/scalekit.v1.emails.EmailService/ListEmailTemplates',
                request_serializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.ListEmailTemplateRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.ListEmailTemplateResponse.FromString,
                )
        self.DeleteEmailTemplate = channel.unary_unary(
                '/scalekit.v1.emails.EmailService/DeleteEmailTemplate',
                request_serializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.DeleteEmailTemplateRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.CreateEmailServer = channel.unary_unary(
                '/scalekit.v1.emails.EmailService/CreateEmailServer',
                request_serializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.CreateEmailServerRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.CreateEmailServerResponse.FromString,
                )
        self.UpdateEmailServerSettings = channel.unary_unary(
                '/scalekit.v1.emails.EmailService/UpdateEmailServerSettings',
                request_serializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.PatchEmailServerSettingsRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.GetEmailServerResponse.FromString,
                )
        self.EnableEmailServer = channel.unary_unary(
                '/scalekit.v1.emails.EmailService/EnableEmailServer',
                request_serializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.EnableEmailServerRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.EnableEmailServerResponse.FromString,
                )
        self.DisableEmailServer = channel.unary_unary(
                '/scalekit.v1.emails.EmailService/DisableEmailServer',
                request_serializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.DisableEmailServerRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetEmailServer = channel.unary_unary(
                '/scalekit.v1.emails.EmailService/GetEmailServer',
                request_serializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.GetEmailServerRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.GetEmailServerResponse.FromString,
                )
        self.ListEmailServers = channel.unary_unary(
                '/scalekit.v1.emails.EmailService/ListEmailServers',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.ListEmailServerResponse.FromString,
                )
        self.DeleteEmailServer = channel.unary_unary(
                '/scalekit.v1.emails.EmailService/DeleteEmailServer',
                request_serializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.DeleteEmailServerRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )


class EmailServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetTemplatePlaceholders(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTemplateUseCases(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateEmailTemplate(self, request, context):
        """For templates

        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateEmailTemplate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetEmailConfiguration(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpsertEmailConfiguration(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EnableEmailTemplate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DisableEmailTemplate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetEmailTemplate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListEmailTemplates(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteEmailTemplate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateEmailServer(self, request, context):
        """Email Server Services
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateEmailServerSettings(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EnableEmailServer(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DisableEmailServer(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetEmailServer(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListEmailServers(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteEmailServer(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_EmailServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetTemplatePlaceholders': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTemplatePlaceholders,
                    request_deserializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.GetPlaceholdersRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.GetPlaceholdersResponse.SerializeToString,
            ),
            'GetTemplateUseCases': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTemplateUseCases,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.GetTemplateUseCasesResponse.SerializeToString,
            ),
            'CreateEmailTemplate': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateEmailTemplate,
                    request_deserializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.CreateEmailTemplateRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.CreateEmailTemplateResponse.SerializeToString,
            ),
            'UpdateEmailTemplate': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateEmailTemplate,
                    request_deserializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.PatchEmailTemplateRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.GetEmailTemplateResponse.SerializeToString,
            ),
            'GetEmailConfiguration': grpc.unary_unary_rpc_method_handler(
                    servicer.GetEmailConfiguration,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.GetEmailConfigurationResponse.SerializeToString,
            ),
            'UpsertEmailConfiguration': grpc.unary_unary_rpc_method_handler(
                    servicer.UpsertEmailConfiguration,
                    request_deserializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.UpsertEmailConfigurationRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.UpsertEmailConfigurationResponse.SerializeToString,
            ),
            'EnableEmailTemplate': grpc.unary_unary_rpc_method_handler(
                    servicer.EnableEmailTemplate,
                    request_deserializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.EnableEmailTemplateRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.EnableEmailTemplateResponse.SerializeToString,
            ),
            'DisableEmailTemplate': grpc.unary_unary_rpc_method_handler(
                    servicer.DisableEmailTemplate,
                    request_deserializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.DisableEmailTemplateRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetEmailTemplate': grpc.unary_unary_rpc_method_handler(
                    servicer.GetEmailTemplate,
                    request_deserializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.GetEmailTemplateRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.GetEmailTemplateResponse.SerializeToString,
            ),
            'ListEmailTemplates': grpc.unary_unary_rpc_method_handler(
                    servicer.ListEmailTemplates,
                    request_deserializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.ListEmailTemplateRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.ListEmailTemplateResponse.SerializeToString,
            ),
            'DeleteEmailTemplate': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteEmailTemplate,
                    request_deserializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.DeleteEmailTemplateRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'CreateEmailServer': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateEmailServer,
                    request_deserializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.CreateEmailServerRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.CreateEmailServerResponse.SerializeToString,
            ),
            'UpdateEmailServerSettings': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateEmailServerSettings,
                    request_deserializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.PatchEmailServerSettingsRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.GetEmailServerResponse.SerializeToString,
            ),
            'EnableEmailServer': grpc.unary_unary_rpc_method_handler(
                    servicer.EnableEmailServer,
                    request_deserializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.EnableEmailServerRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.EnableEmailServerResponse.SerializeToString,
            ),
            'DisableEmailServer': grpc.unary_unary_rpc_method_handler(
                    servicer.DisableEmailServer,
                    request_deserializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.DisableEmailServerRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetEmailServer': grpc.unary_unary_rpc_method_handler(
                    servicer.GetEmailServer,
                    request_deserializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.GetEmailServerRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.GetEmailServerResponse.SerializeToString,
            ),
            'ListEmailServers': grpc.unary_unary_rpc_method_handler(
                    servicer.ListEmailServers,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.ListEmailServerResponse.SerializeToString,
            ),
            'DeleteEmailServer': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteEmailServer,
                    request_deserializer=scalekit_dot_v1_dot_emails_dot_emails__pb2.DeleteEmailServerRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'scalekit.v1.emails.EmailService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class EmailService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetTemplatePlaceholders(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.emails.EmailService/GetTemplatePlaceholders',
            scalekit_dot_v1_dot_emails_dot_emails__pb2.GetPlaceholdersRequest.SerializeToString,
            scalekit_dot_v1_dot_emails_dot_emails__pb2.GetPlaceholdersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTemplateUseCases(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.emails.EmailService/GetTemplateUseCases',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            scalekit_dot_v1_dot_emails_dot_emails__pb2.GetTemplateUseCasesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateEmailTemplate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.emails.EmailService/CreateEmailTemplate',
            scalekit_dot_v1_dot_emails_dot_emails__pb2.CreateEmailTemplateRequest.SerializeToString,
            scalekit_dot_v1_dot_emails_dot_emails__pb2.CreateEmailTemplateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateEmailTemplate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.emails.EmailService/UpdateEmailTemplate',
            scalekit_dot_v1_dot_emails_dot_emails__pb2.PatchEmailTemplateRequest.SerializeToString,
            scalekit_dot_v1_dot_emails_dot_emails__pb2.GetEmailTemplateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetEmailConfiguration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.emails.EmailService/GetEmailConfiguration',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            scalekit_dot_v1_dot_emails_dot_emails__pb2.GetEmailConfigurationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpsertEmailConfiguration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.emails.EmailService/UpsertEmailConfiguration',
            scalekit_dot_v1_dot_emails_dot_emails__pb2.UpsertEmailConfigurationRequest.SerializeToString,
            scalekit_dot_v1_dot_emails_dot_emails__pb2.UpsertEmailConfigurationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EnableEmailTemplate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.emails.EmailService/EnableEmailTemplate',
            scalekit_dot_v1_dot_emails_dot_emails__pb2.EnableEmailTemplateRequest.SerializeToString,
            scalekit_dot_v1_dot_emails_dot_emails__pb2.EnableEmailTemplateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DisableEmailTemplate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.emails.EmailService/DisableEmailTemplate',
            scalekit_dot_v1_dot_emails_dot_emails__pb2.DisableEmailTemplateRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetEmailTemplate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.emails.EmailService/GetEmailTemplate',
            scalekit_dot_v1_dot_emails_dot_emails__pb2.GetEmailTemplateRequest.SerializeToString,
            scalekit_dot_v1_dot_emails_dot_emails__pb2.GetEmailTemplateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListEmailTemplates(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.emails.EmailService/ListEmailTemplates',
            scalekit_dot_v1_dot_emails_dot_emails__pb2.ListEmailTemplateRequest.SerializeToString,
            scalekit_dot_v1_dot_emails_dot_emails__pb2.ListEmailTemplateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteEmailTemplate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.emails.EmailService/DeleteEmailTemplate',
            scalekit_dot_v1_dot_emails_dot_emails__pb2.DeleteEmailTemplateRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateEmailServer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.emails.EmailService/CreateEmailServer',
            scalekit_dot_v1_dot_emails_dot_emails__pb2.CreateEmailServerRequest.SerializeToString,
            scalekit_dot_v1_dot_emails_dot_emails__pb2.CreateEmailServerResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateEmailServerSettings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.emails.EmailService/UpdateEmailServerSettings',
            scalekit_dot_v1_dot_emails_dot_emails__pb2.PatchEmailServerSettingsRequest.SerializeToString,
            scalekit_dot_v1_dot_emails_dot_emails__pb2.GetEmailServerResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EnableEmailServer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.emails.EmailService/EnableEmailServer',
            scalekit_dot_v1_dot_emails_dot_emails__pb2.EnableEmailServerRequest.SerializeToString,
            scalekit_dot_v1_dot_emails_dot_emails__pb2.EnableEmailServerResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DisableEmailServer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.emails.EmailService/DisableEmailServer',
            scalekit_dot_v1_dot_emails_dot_emails__pb2.DisableEmailServerRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetEmailServer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.emails.EmailService/GetEmailServer',
            scalekit_dot_v1_dot_emails_dot_emails__pb2.GetEmailServerRequest.SerializeToString,
            scalekit_dot_v1_dot_emails_dot_emails__pb2.GetEmailServerResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListEmailServers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.emails.EmailService/ListEmailServers',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            scalekit_dot_v1_dot_emails_dot_emails__pb2.ListEmailServerResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteEmailServer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.emails.EmailService/DeleteEmailServer',
            scalekit_dot_v1_dot_emails_dot_emails__pb2.DeleteEmailServerRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



from typing import List, Optional
from datetime import datetime
from pydantic import BaseModel, Field
from google.protobuf import timestamp_pb2

from scalekit.v1.connected_accounts.connected_accounts_pb2 import ConnectorStatus, ConnectorType


class ConnectedAccountForList(BaseModel):
    """Connected account item in list response with one-to-one mapping to proto ConnectedAccountForList"""
    
    identifier: Optional[str] = Field(
        None,
        description="Unique identifier for the connected account"
    )
    provider: Optional[str] = Field(
        None,
        description="Provider of the connected account (e.g., 'google', 'slack')"
    )
    status: Optional[str] = Field(
        None, 
        description="Status of the connected account"
    )
    authorization_type: Optional[str] = Field(
        None,
        description="Type of authorization used for the connected account"
    )
    token_expires_at: Optional[datetime] = Field(
        None,
        description="Timestamp when the token expires"
    )
    updated_at: Optional[datetime] = Field(
        None,
        description="Timestamp when the connected account was last updated"
    )
    connector: Optional[str] = Field(
        None,
        description="Connector identifier"
    )
    last_used_at: Optional[datetime] = Field(
        None,
        description="Timestamp when the connected account was last used"
    )

    @classmethod
    def from_proto(cls, proto_account) -> 'ConnectedAccountForList':
        """
        Create ConnectedAccountForList from protobuf ConnectedAccountForList
        
        :param proto_account: The protobuf ConnectedAccountForList object
        :type proto_account: ConnectedAccountForList (from connected_accounts_pb2)
        
        :returns:
            ConnectedAccountForList instance
        """
        # Convert protobuf Timestamps to datetime
        token_expires_at = None
        if proto_account.token_expires_at:
            token_expires_at = proto_account.token_expires_at.ToDatetime()
            
        updated_at = None
        if proto_account.updated_at:
            updated_at = proto_account.updated_at.ToDatetime()
            
        last_used_at = None
        if proto_account.last_used_at:
            last_used_at = proto_account.last_used_at.ToDatetime()
            
        return cls(
            identifier=proto_account.identifier if proto_account.identifier else None,
            provider=proto_account.provider if proto_account.provider else None,
            status= ConnectorStatus.Name(proto_account.status) if proto_account.status else None,
            authorization_type=ConnectorType.Name(proto_account.authorization_type) if proto_account.authorization_type else None,
            token_expires_at=token_expires_at,
            updated_at=updated_at,
            connector=proto_account.connector if proto_account.connector else None,
            last_used_at=last_used_at
        )

    def to_dict(self) -> dict:
        """
        Convert to dictionary representation
        
        :returns:
            Dictionary representation of the connected account
        """
        return {
            "identifier": self.identifier,
            "provider": self.provider,
            "status": self.status,
            "authorization_type": self.authorization_type,
            "token_expires_at": self.token_expires_at.isoformat() if self.token_expires_at else None,
            "updated_at": self.updated_at.isoformat() if self.updated_at else None,
            "connector": self.connector,
            "last_used_at": self.last_used_at.isoformat() if self.last_used_at else None
        }

    class Config:
        """Pydantic configuration"""
        validate_assignment = True
        json_encoders = {
            datetime: lambda v: v.isoformat() if v else None
        }


class ListConnectedAccountsResponse(BaseModel):
    """List connected accounts response with one-to-one mapping to proto ListConnectedAccountsResponse"""
    
    connected_accounts: List[ConnectedAccountForList] = Field(
        default_factory=list,
        description="List of connected accounts"
    )
    total_count: Optional[int] = Field(
        None,
        description="Total number of connected accounts matching the request",
        alias="total_size"
    )
    next_page_token: Optional[str] = Field(
        None,
        description="Token for the next page of results"
    )
    previous_page_token: Optional[str] = Field(
        None,
        description="Token for the previous page of results",
        alias="prev_page_token"
    )

    @classmethod
    def from_proto(cls, proto_response) -> 'ListConnectedAccountsResponse':
        """
        Create ListConnectedAccountsResponse from protobuf ListConnectedAccountsResponse
        
        :param proto_response: The protobuf ListConnectedAccountsResponse object
        :type proto_response: ListConnectedAccountsResponse (from connected_accounts_pb2)
        
        :returns:
            ListConnectedAccountsResponse instance
        """
        # Convert protobuf connected accounts to our model
        connected_accounts = []
        for proto_account in proto_response.connected_accounts:
            connected_accounts.append(ConnectedAccountForList.from_proto(proto_account))
            
        return cls(
            connected_accounts=connected_accounts,
            total_count=proto_response.total_size if proto_response.total_size else None,
            next_page_token=proto_response.next_page_token if proto_response.next_page_token else None,
            previous_page_token=proto_response.prev_page_token if proto_response.prev_page_token else None
        )

    def to_dict(self) -> dict:
        """
        Convert to dictionary representation
        
        :returns:
            Dictionary representation of the response
        """
        return {
            "connected_accounts": [account.to_dict() for account in self.connected_accounts],
            "total_count": self.total_count,
            "next_page_token": self.next_page_token,
            "previous_page_token": self.previous_page_token
        }

    class Config:
        """Pydantic configuration"""
        validate_assignment = True
        populate_by_name = True
        json_encoders = {
            datetime: lambda v: v.isoformat() if v else None
        }


# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from scalekit.v1.auth import totp_pb2 as scalekit_dot_v1_dot_auth_dot_totp__pb2


class TOTPServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.RegisterTOTP = channel.unary_unary(
                '/scalekit.v1.auth.totp.TOTPService/RegisterTOTP',
                request_serializer=scalekit_dot_v1_dot_auth_dot_totp__pb2.TOTPRegistrationRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_auth_dot_totp__pb2.TOTPRegistrationResponse.FromString,
                )
        self.EnableTOTP = channel.unary_unary(
                '/scalekit.v1.auth.totp.TOTPService/EnableTOTP',
                request_serializer=scalekit_dot_v1_dot_auth_dot_totp__pb2.EnableRegistrationTOTPRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_auth_dot_totp__pb2.EnableRegistrationTOTPResponse.FromString,
                )
        self.VerifyUserCode = channel.unary_unary(
                '/scalekit.v1.auth.totp.TOTPService/VerifyUserCode',
                request_serializer=scalekit_dot_v1_dot_auth_dot_totp__pb2.VerifyUserCodeRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_auth_dot_totp__pb2.VerifyCodeResponse.FromString,
                )
        self.VerifyRegistrationCode = channel.unary_unary(
                '/scalekit.v1.auth.totp.TOTPService/VerifyRegistrationCode',
                request_serializer=scalekit_dot_v1_dot_auth_dot_totp__pb2.VerifyRegistrationCodeRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_auth_dot_totp__pb2.VerifyCodeResponse.FromString,
                )
        self.DisableTOTP = channel.unary_unary(
                '/scalekit.v1.auth.totp.TOTPService/DisableTOTP',
                request_serializer=scalekit_dot_v1_dot_auth_dot_totp__pb2.DisableRegistrationTOTPRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )


class TOTPServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def RegisterTOTP(self, request, context):
        """Enable TOTP for a user
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EnableTOTP(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def VerifyUserCode(self, request, context):
        """Verify TOTP code for a user
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def VerifyRegistrationCode(self, request, context):
        """Verify TOTP code for a registration
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DisableTOTP(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_TOTPServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'RegisterTOTP': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterTOTP,
                    request_deserializer=scalekit_dot_v1_dot_auth_dot_totp__pb2.TOTPRegistrationRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_auth_dot_totp__pb2.TOTPRegistrationResponse.SerializeToString,
            ),
            'EnableTOTP': grpc.unary_unary_rpc_method_handler(
                    servicer.EnableTOTP,
                    request_deserializer=scalekit_dot_v1_dot_auth_dot_totp__pb2.EnableRegistrationTOTPRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_auth_dot_totp__pb2.EnableRegistrationTOTPResponse.SerializeToString,
            ),
            'VerifyUserCode': grpc.unary_unary_rpc_method_handler(
                    servicer.VerifyUserCode,
                    request_deserializer=scalekit_dot_v1_dot_auth_dot_totp__pb2.VerifyUserCodeRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_auth_dot_totp__pb2.VerifyCodeResponse.SerializeToString,
            ),
            'VerifyRegistrationCode': grpc.unary_unary_rpc_method_handler(
                    servicer.VerifyRegistrationCode,
                    request_deserializer=scalekit_dot_v1_dot_auth_dot_totp__pb2.VerifyRegistrationCodeRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_auth_dot_totp__pb2.VerifyCodeResponse.SerializeToString,
            ),
            'DisableTOTP': grpc.unary_unary_rpc_method_handler(
                    servicer.DisableTOTP,
                    request_deserializer=scalekit_dot_v1_dot_auth_dot_totp__pb2.DisableRegistrationTOTPRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'scalekit.v1.auth.totp.TOTPService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class TOTPService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def RegisterTOTP(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.auth.totp.TOTPService/RegisterTOTP',
            scalekit_dot_v1_dot_auth_dot_totp__pb2.TOTPRegistrationRequest.SerializeToString,
            scalekit_dot_v1_dot_auth_dot_totp__pb2.TOTPRegistrationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EnableTOTP(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.auth.totp.TOTPService/EnableTOTP',
            scalekit_dot_v1_dot_auth_dot_totp__pb2.EnableRegistrationTOTPRequest.SerializeToString,
            scalekit_dot_v1_dot_auth_dot_totp__pb2.EnableRegistrationTOTPResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def VerifyUserCode(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.auth.totp.TOTPService/VerifyUserCode',
            scalekit_dot_v1_dot_auth_dot_totp__pb2.VerifyUserCodeRequest.SerializeToString,
            scalekit_dot_v1_dot_auth_dot_totp__pb2.VerifyCodeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def VerifyRegistrationCode(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.auth.totp.TOTPService/VerifyRegistrationCode',
            scalekit_dot_v1_dot_auth_dot_totp__pb2.VerifyRegistrationCodeRequest.SerializeToString,
            scalekit_dot_v1_dot_auth_dot_totp__pb2.VerifyCodeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DisableTOTP(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.auth.totp.TOTPService/DisableTOTP',
            scalekit_dot_v1_dot_auth_dot_totp__pb2.DisableRegistrationTOTPRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



from datetime import datetime

from faker import Faker

from basetest import BaseTest
from scalekit.v1.organizations.organizations_pb2 import CreateOrganization, UpdateOrganization


class TestOrganization(BaseTest):
    """ Class definition for Test Organization Class """

    def setUp(self):
        """ """
        self.org_id = None

    def test_create_organization(self):
        """ Method to test create organization """
        display_name = Faker().company()
        external_id = Faker().uuid4()
        organization = CreateOrganization(display_name=display_name, external_id=external_id)
        response = self.scalekit_client.organization.create_organization(organization=organization)
        self.assertEqual(response[1].code().name, "OK")
        self.assertTrue(response[0] is not None)
        self.assertEqual(response[0].organization.display_name, display_name)
        self.assertEqual(response[0].organization.external_id, external_id)
        self.org_id = response[0].organization.id

    def test_get_organization(self):
        """  Method to test get organization """
        organization = CreateOrganization(display_name=Faker().company(), external_id=Faker().uuid4())
        org_response = self.scalekit_client.organization.create_organization(organization=organization)
        self.org_id = org_response[0].organization.id

        response = self.scalekit_client.organization.get_organization(organization_id=self.org_id)
        self.assertEqual(response[1].code().name, "OK")
        self.assertTrue(response[0] is not None)
        self.assertEqual(response[0].organization.id, self.org_id)
        self.assertEqual(response[0].organization.display_name, organization.display_name)

    def test_get_organization_by_external_id(self):
        """  Method to test get organization by external id """
        display_name = Faker().company()
        external_id = Faker().uuid4()
        organization = CreateOrganization(display_name=display_name, external_id=external_id)
        org_response = self.scalekit_client.organization.create_organization(organization=organization)
        self.org_id = org_response[0].organization.id

        response = self.scalekit_client.organization.get_organization_by_external_id(external_id=external_id)
        self.assertEqual(response[1].code().name, "OK")
        self.assertTrue(response[0] is not None)
        self.assertEqual(response[0].organization.id, self.org_id)
        self.assertEqual(response[0].organization.display_name, organization.display_name)

    def test_list_organizations(self):
        """ Method to test list organizations """
        organization = CreateOrganization(display_name=Faker().company(), external_id=Faker().uuid4())
        org_response = self.scalekit_client.organization.create_organization(organization=organization)
        self.org_id = org_response[0].organization.id

        response = self.scalekit_client.organization.list_organizations(page_size=10)
        self.assertEqual(response[1].code().name, "OK")
        self.assertTrue(response[0] is not None)
        self.assertTrue(len(response[0].organizations) > 0)
        self.assertEqual(response[0].organizations[0].id, self.org_id)
        self.assertEqual(response[0].organizations[0].display_name, organization.display_name)

    def test_update_organization(self):
        """ Method to test update organization """
        organization = CreateOrganization(display_name=Faker().company(), external_id=Faker().uuid4())
        org_response = self.scalekit_client.organization.create_organization(organization=organization)
        self.org_id = org_response[0].organization.id

        updated_display_name = Faker().company()
        updated_external_id = Faker().uuid4()
        metadata = {'key1': 'Value1', 'key2': 'Value2'}
        update_organization = UpdateOrganization(
            display_name=updated_display_name, external_id=updated_external_id, metadata=metadata)
        response = self.scalekit_client.organization.update_organization(
            organization_id=self.org_id, organization=update_organization
        )
        self.assertEqual(response[1].code().name, "OK")
        self.assertTrue(response[0] is not None)
        self.assertEqual(response[0].organization.id, self.org_id)
        self.assertEqual(response[0].organization.display_name, updated_display_name)
        self.assertEqual(response[0].organization.metadata, metadata)
        self.assertEqual(response[0].organization.external_id, updated_external_id)

    def test_update_organization_by_external_id(self):
        """ Method to test update organization """
        display_name = Faker().company()
        external_id = Faker().uuid4()
        organization = CreateOrganization(display_name=display_name, external_id=external_id)
        org_response = self.scalekit_client.organization.create_organization(organization=organization)
        self.org_id = org_response[0].organization.id

        updated_display_name = Faker().company()
        metadata = {'key1': 'Value1', 'key2': 'Value2'}
        update_organization = UpdateOrganization(display_name=updated_display_name, metadata=metadata)
        response = self.scalekit_client.organization.update_organization_by_external_id(
            external_id=external_id, organization=update_organization
        )
        self.assertEqual(response[1].code().name, "OK")
        self.assertTrue(response[0] is not None)
        self.assertEqual(response[0].organization.id, self.org_id)
        self.assertEqual(response[0].organization.display_name, updated_display_name)
        self.assertEqual(response[0].organization.metadata, metadata)
        self.assertEqual(response[0].organization.external_id, external_id)

    def test_delete_organization(self):
        """ Method to test delete organization """
        organization = CreateOrganization(display_name=Faker().company(), external_id=Faker().uuid4())
        org_response = self.scalekit_client.organization.create_organization(organization=organization)
        self.org_id = org_response[0].organization.id

        response = self.scalekit_client.organization.delete_organization(organization_id=self.org_id)
        self.assertEqual(response[1].code().name, "OK")

        try:
            self.scalekit_client.organization.get_organization(organization_id=self.org_id)
        except Exception as exp:
            self.assertEqual(exp.args[0], "organization with id &{" + f"{self.org_id}" + "} was not found")
            self.org_id = None

    def test_generate_portal_link(self):
        """ Method to test generate portal link """
        organization = CreateOrganization(display_name=Faker().company(), external_id=Faker().uuid4())
        org_response = self.scalekit_client.organization.create_organization(organization=organization)
        self.org_id = org_response[0].organization.id

        response = self.scalekit_client.organization.generate_portal_link(organization_id=self.org_id)
        self.assertIsNotNone(response.id)
        self.assertIsNotNone(response.location)
        assert response.expire_time.seconds > datetime.now().timestamp()

    def test_update_organization_settings(self):
        """ Method to test update organization settings """
        organization = CreateOrganization(display_name=Faker().company(), external_id=Faker().uuid4())
        org_response = self.scalekit_client.organization.create_organization(organization=organization)
        self.org_id = org_response[0].organization.id

        settings = [{"name": "sso", "enabled": True}, {"name": "dir_sync", "enabled": False}]
        response = self.scalekit_client.organization.update_organization_settings(
            organization_id=self.org_id, settings=settings
        )
        self.assertEqual(response[1].code().name, "OK")
        self.assertEqual(response[0].organization.id, self.org_id)
        if response[0].organization.settings.features[0].name == 'sso':
            self.assertTrue(response[0].organization.settings.features[0].enabled)
            self.assertFalse(response[0].organization.settings.features[1].enabled)
        else:
            self.assertTrue(response[0].organization.settings.features[1].enabled)
            self.assertFalse(response[0].organization.settings.features[0].enabled)

    def tearDown(self):
        """ Method to clean up after test """
        if self.org_id:
            self.scalekit_client.organization.delete_organization(organization_id=self.org_id)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: scalekit/v1/events/events.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2
from scalekit.v1.commons import commons_pb2 as scalekit_dot_v1_dot_commons_dot_commons__pb2
from scalekit.v1.options import options_pb2 as scalekit_dot_v1_dot_options_dot_options__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fscalekit/v1/events/events.proto\x12\x12scalekit.v1.events\x1a\x1b\x62uf/validate/validate.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a.protoc-gen-openapiv2/options/annotations.proto\x1a!scalekit/v1/commons/commons.proto\x1a!scalekit/v1/options/options.proto\"n\n\x16SendCustomEventRequest\x12%\n\nevent_type\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\teventType\x12-\n\x05\x65vent\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructR\x05\x65vent\"4\n\x17SendCustomEventResponse\x12\x19\n\x08\x65vent_id\x18\x01 \x01(\tR\x07\x65ventId\"n\n\x16IEventPaginationTokens\x12\x1a\n\x08NextPage\x18\x01 \x01(\tR\x08NextPage\x12\"\n\x0cPreviousPage\x18\x02 \x01(\tR\x0cPreviousPage\x12\x14\n\x05Total\x18\x03 \x01(\rR\x05Total\"\x88\x01\n\x11ListEventsRequest\x12\x37\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x1f.scalekit.v1.events.EventFilterR\x06\x66ilter\x12\x1b\n\tpage_size\x18\x02 \x01(\rR\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"\xbe\x01\n\x12ListEventsResponse\x12\x39\n\x06\x65vents\x18\x01 \x03(\x0b\x32!.scalekit.v1.events.ScalekitEventR\x06\x65vents\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12&\n\x0fprev_page_token\x18\x03 \x01(\tR\rprevPageToken\x12\x1d\n\ntotal_size\x18\x04 \x01(\rR\ttotalSize\"\xc6\x05\n\x06IEvent\x12!\n\x0cspec_version\x18\x01 \x01(\tR\x0bspecVersion\x12\x19\n\x02id\x18\x02 \x01(\tB\t\xbaH\x06r\x04\x10\x01\x18 R\x02id\x12\x12\n\x04type\x18\x03 \x01(\tR\x04type\x12;\n\x0boccurred_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\noccurredAt\x12/\n\x05\x61\x63tor\x18\x05 \x01(\x0b\x32\x19.scalekit.v1.events.ActorR\x05\x61\x63tor\x12\x1b\n\ttenant_id\x18\x06 \x01(\tR\x08tenantId\x12\x32\n\x06target\x18\x07 \x01(\x0b\x32\x1a.scalekit.v1.events.TargetR\x06target\x12\x16\n\x06source\x18\x08 \x01(\tR\x06source\x12+\n\x04\x64\x61ta\x18\t \x01(\x0b\x32\x17.google.protobuf.StructR\x04\x64\x61ta\x12\x32\n\x08old_data\x18\n \x01(\x0b\x32\x17.google.protobuf.StructR\x07oldData\x12Z\n\x07\x63ontext\x18\x0b \x03(\x0b\x32\'.scalekit.v1.events.IEvent.ContextEntryB\x17\xbaH\x14\x9a\x01\x11\"\x06r\x04\x10\x03\x18\x19*\x07r\x05\x10\x01\x18\xd0\x0fR\x07\x63ontext\x12]\n\x08metadata\x18\x0c \x03(\x0b\x32(.scalekit.v1.events.IEvent.MetadataEntryB\x17\xbaH\x14\x9a\x01\x11\"\x06r\x04\x10\x03\x18\x19*\x07r\x05\x10\x01\x18\xd0\x0fR\x08metadata\x1a:\n\x0c\x43ontextEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1a;\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xfb\x05\n\x05\x45vent\x12!\n\x0cspec_version\x18\x01 \x01(\tR\x0bspecVersion\x12\x19\n\x02id\x18\x02 \x01(\tB\t\xbaH\x06r\x04\x10\x01\x18 R\x02id\x12\x12\n\x04type\x18\x03 \x01(\tR\x04type\x12;\n\x0boccurred_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\noccurredAt\x12/\n\x05\x61\x63tor\x18\x05 \x01(\x0b\x32\x19.scalekit.v1.events.ActorR\x05\x61\x63tor\x12\x1b\n\ttenant_id\x18\x06 \x01(\tR\x08tenantId\x12\x32\n\x06target\x18\x07 \x01(\x0b\x32\x1a.scalekit.v1.events.TargetR\x06target\x12\x16\n\x06source\x18\x08 \x01(\tR\x06source\x12+\n\x04\x64\x61ta\x18\t \x01(\x0b\x32\x17.google.protobuf.StructR\x04\x64\x61ta\x12\x32\n\x08old_data\x18\n \x01(\x0b\x32\x17.google.protobuf.StructR\x07oldData\x12Y\n\x07\x63ontext\x18\x0b \x03(\x0b\x32&.scalekit.v1.events.Event.ContextEntryB\x17\xbaH\x14\x9a\x01\x11\"\x06r\x04\x10\x03\x18\x19*\x07r\x05\x10\x01\x18\xd0\x0fR\x07\x63ontext\x12\\\n\x08metadata\x18\x0c \x03(\x0b\x32\'.scalekit.v1.events.Event.MetadataEntryB\x17\xbaH\x14\x9a\x01\x11\"\x06r\x04\x10\x03\x18\x19*\x07r\x05\x10\x01\x18\xd0\x0fR\x08metadata\x12\x36\n\x06object\x18\r \x01(\x0e\x32\x1e.scalekit.v1.events.ObjectTypeR\x06object\x1a:\n\x0c\x43ontextEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1a;\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"K\n\x05\x41\x63tor\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x32\n\x04type\x18\x02 \x01(\x0e\x32\x1e.scalekit.v1.events.EventActorR\x04type\"M\n\x06Target\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x33\n\x04type\x18\x02 \x01(\x0e\x32\x1f.scalekit.v1.events.EventTargetR\x04type\"\xf1\x03\n\x0cIEventFilter\x12\x1f\n\x0b\x65vent_types\x18\x01 \x03(\tR\neventTypes\x12\x39\n\nstart_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tstartTime\x12\x35\n\x08\x65nd_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x07\x65ndTime\x12\x1b\n\ttenant_id\x18\x04 \x01(\tR\x08tenantId\x12\x32\n\x06target\x18\x05 \x01(\x0b\x32\x1a.scalekit.v1.events.TargetR\x06target\x12\x32\n\x06source\x18\x06 \x01(\x0e\x32\x1a.scalekit.v1.events.SourceR\x06source\x12\x63\n\x08metadata\x18\x07 \x03(\x0b\x32..scalekit.v1.events.IEventFilter.MetadataEntryB\x17\xbaH\x14\x9a\x01\x11\"\x06r\x04\x10\x03\x18\x19*\x07r\x05\x10\x01\x18\xd0\x0fR\x08metadata\x12\'\n\x0finternal_events\x18\x08 \x03(\tR\x0einternalEvents\x1a;\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xa5\x02\n\x0b\x45ventFilter\x12\x1f\n\x0b\x65vent_types\x18\x01 \x03(\tR\neventTypes\x12\x39\n\nstart_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tstartTime\x12\x35\n\x08\x65nd_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x07\x65ndTime\x12\'\n\x0forganization_id\x18\x04 \x01(\tR\x0eorganizationId\x12\x32\n\x06source\x18\x05 \x01(\x0e\x32\x1a.scalekit.v1.events.SourceR\x06source\x12&\n\x0f\x61uth_request_id\x18\x06 \x01(\tR\rauthRequestId\"\x9a\x03\n\rScalekitEvent\x12!\n\x0cspec_version\x18\x01 \x01(\tR\x0bspecVersion\x12\x1e\n\x02id\x18\x02 \x01(\tB\x0e\xbaH\x0br\t\x10\x01\x18 :\x03\x65vtR\x02id\x12\x12\n\x04type\x18\x03 \x01(\tR\x04type\x12;\n\x0boccurred_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\noccurredAt\x12%\n\x0e\x65nvironment_id\x18\x06 \x01(\tR\renvironmentId\x12,\n\x0forganization_id\x18\x07 \x01(\tH\x00R\x0eorganizationId\x88\x01\x01\x12\x36\n\x06object\x18\x08 \x01(\x0e\x32\x1e.scalekit.v1.events.ObjectTypeR\x06object\x12+\n\x04\x64\x61ta\x18\t \x01(\x0b\x32\x17.google.protobuf.StructR\x04\x64\x61ta\x12!\n\x0c\x64isplay_name\x18\n \x01(\tR\x0b\x64isplayNameB\x12\n\x10_organization_idJ\x04\x08\x05\x10\x06*D\n\nEventActor\x12\x15\n\x11\x41\x43TOR_UNSPECIFIED\x10\x00\x12\t\n\x05HUMAN\x10\x01\x12\x0b\n\x07MACHINE\x10\x02\x12\x07\n\x03\x41PI\x10\x03*<\n\x06Source\x12\x16\n\x12SOURCE_UNSPECIFIED\x10\x00\x12\x0c\n\x08SCALEKIT\x10\x01\x12\x0c\n\x08\x44IR_SYNC\x10\x02*\x9f\x01\n\x0b\x45ventTarget\x12\x1c\n\x18\x45VENT_TARGET_UNSPECIFIED\x10\x00\x12\r\n\tWORKSPACE\x10\x01\x12\x0f\n\x0b\x45NVIRONMENT\x10\x02\x12\x10\n\x0cORGANIZATION\x10\x03\x12\x08\n\x04USER\x10\x04\x12\x0b\n\x07SESSION\x10\x05\x12\x0c\n\x08TEMPLATE\x10\x06\x12\x10\n\x0c\x45MAIL_SERVER\x10\x07\x12\t\n\x05\x45MAIL\x10\x08*M\n\rEventCategory\x12\x1c\n\x18\x45VENT_SOURCE_UNSPECIFIED\x10\x00\x12\x08\n\x04\x43ORE\x10\x01\x12\x07\n\x03SSO\x10\x02\x12\x0b\n\x07\x44IRSYNC\x10\x03*\xdf\x04\n\nObjectType\x12\x1b\n\x17OBJECT_TYPE_UNSPECIFIED\x10\x00\x12\r\n\tWorkspace\x10\x01\x12\x0f\n\x0b\x45nvironment\x10\x02\x12\x10\n\x0cOrganization\x10\x03\x12\x0e\n\nConnection\x10\x04\x12\x08\n\x04User\x10\x05\x12\x08\n\x04Role\x10\x06\x12\x14\n\x10\x43ustomAttributes\x10\x07\x12\r\n\tDirectory\x10\x08\x12\x11\n\rDirectoryUser\x10\t\x12\x12\n\x0e\x44irectoryGroup\x10\n\x12\x0b\n\x07Session\x10\x0b\x12\x0c\n\x08Template\x10\x0c\x12\x07\n\x03Job\x10\r\x12\n\n\x06\x44omain\x10\x0e\x12\x0f\n\x0b\x45mailServer\x10\x0f\x12\t\n\x05\x45mail\x10\x10\x12\x0f\n\x0b\x41uthRequest\x10\x11\x12\x0f\n\x0bSAMLRequest\x10\x12\x12\x10\n\x0cSAMLResponse\x10\x13\x12\x0f\n\x0bTokenClaims\x10\x14\x12\x11\n\rOIDCReqParams\x10\x15\x12\x12\n\x0eOIDCRespClaims\x10\x16\x12\x0c\n\x08SSOError\x10\x17\x12\x10\n\x0cGenericError\x10\x18\x12\x11\n\rRefreshTokens\x10\x19\x12\x15\n\x11\x45ndSessionRequest\x10\x1a\x12\x15\n\x11LogoutTokenClaims\x10\x1b\x12\x11\n\rOAuthResponse\x10\x1c\x12\x08\n\x04JSON\x10\x1d\x12\x0c\n\x08SKErrors\x10\x1e\x12\x11\n\rOrgMembership\x10\x1f\x12\x0f\n\x0bUserProfile\x10 \x12\x17\n\x13IDPInitiatedPayload\x10!\x12\x11\n\rDeviceDetails\x10\"2\xc2\x02\n\rEventsService\x12\x81\x01\n\nListEvents\x12%.scalekit.v1.events.ListEventsRequest\x1a&.scalekit.v1.events.ListEventsResponse\"$\x82\xb5\x18\x02\x18t\x82\xd3\xe4\x93\x02\x18\"\x0e/api/v1/events:\x06\x66ilter\x12\xac\x01\n\x0fSendCustomEvent\x12*.scalekit.v1.events.SendCustomEventRequest\x1a+.scalekit.v1.events.SendCustomEventResponse\"@\x82\xb5\x18\x02\x18p\x82\xd3\xe4\x93\x02\x34\"+/api/v1/events/frontend_events/{event_type}:\x05\x65ventB2Z0github.com/scalekit-inc/scalekit/pkg/grpc/eventsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'scalekit.v1.events.events_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z0github.com/scalekit-inc/scalekit/pkg/grpc/events'
  _globals['_SENDCUSTOMEVENTREQUEST'].fields_by_name['event_type']._loaded_options = None
  _globals['_SENDCUSTOMEVENTREQUEST'].fields_by_name['event_type']._serialized_options = b'\272H\003\310\001\001'
  _globals['_IEVENT_CONTEXTENTRY']._loaded_options = None
  _globals['_IEVENT_CONTEXTENTRY']._serialized_options = b'8\001'
  _globals['_IEVENT_METADATAENTRY']._loaded_options = None
  _globals['_IEVENT_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_IEVENT'].fields_by_name['id']._loaded_options = None
  _globals['_IEVENT'].fields_by_name['id']._serialized_options = b'\272H\006r\004\020\001\030 '
  _globals['_IEVENT'].fields_by_name['context']._loaded_options = None
  _globals['_IEVENT'].fields_by_name['context']._serialized_options = b'\272H\024\232\001\021\"\006r\004\020\003\030\031*\007r\005\020\001\030\320\017'
  _globals['_IEVENT'].fields_by_name['metadata']._loaded_options = None
  _globals['_IEVENT'].fields_by_name['metadata']._serialized_options = b'\272H\024\232\001\021\"\006r\004\020\003\030\031*\007r\005\020\001\030\320\017'
  _globals['_EVENT_CONTEXTENTRY']._loaded_options = None
  _globals['_EVENT_CONTEXTENTRY']._serialized_options = b'8\001'
  _globals['_EVENT_METADATAENTRY']._loaded_options = None
  _globals['_EVENT_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_EVENT'].fields_by_name['id']._loaded_options = None
  _globals['_EVENT'].fields_by_name['id']._serialized_options = b'\272H\006r\004\020\001\030 '
  _globals['_EVENT'].fields_by_name['context']._loaded_options = None
  _globals['_EVENT'].fields_by_name['context']._serialized_options = b'\272H\024\232\001\021\"\006r\004\020\003\030\031*\007r\005\020\001\030\320\017'
  _globals['_EVENT'].fields_by_name['metadata']._loaded_options = None
  _globals['_EVENT'].fields_by_name['metadata']._serialized_options = b'\272H\024\232\001\021\"\006r\004\020\003\030\031*\007r\005\020\001\030\320\017'
  _globals['_IEVENTFILTER_METADATAENTRY']._loaded_options = None
  _globals['_IEVENTFILTER_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_IEVENTFILTER'].fields_by_name['metadata']._loaded_options = None
  _globals['_IEVENTFILTER'].fields_by_name['metadata']._serialized_options = b'\272H\024\232\001\021\"\006r\004\020\003\030\031*\007r\005\020\001\030\320\017'
  _globals['_SCALEKITEVENT'].fields_by_name['id']._loaded_options = None
  _globals['_SCALEKITEVENT'].fields_by_name['id']._serialized_options = b'\272H\013r\t\020\001\030 :\003evt'
  _globals['_EVENTSSERVICE'].methods_by_name['ListEvents']._loaded_options = None
  _globals['_EVENTSSERVICE'].methods_by_name['ListEvents']._serialized_options = b'\202\265\030\002\030t\202\323\344\223\002\030\"\016/api/v1/events:\006filter'
  _globals['_EVENTSSERVICE'].methods_by_name['SendCustomEvent']._loaded_options = None
  _globals['_EVENTSSERVICE'].methods_by_name['SendCustomEvent']._serialized_options = b'\202\265\030\002\030p\202\323\344\223\0024\"+/api/v1/events/frontend_events/{event_type}:\005event'
  _globals['_EVENTACTOR']._serialized_start=3841
  _globals['_EVENTACTOR']._serialized_end=3909
  _globals['_SOURCE']._serialized_start=3911
  _globals['_SOURCE']._serialized_end=3971
  _globals['_EVENTTARGET']._serialized_start=3974
  _globals['_EVENTTARGET']._serialized_end=4133
  _globals['_EVENTCATEGORY']._serialized_start=4135
  _globals['_EVENTCATEGORY']._serialized_end=4212
  _globals['_OBJECTTYPE']._serialized_start=4215
  _globals['_OBJECTTYPE']._serialized_end=4822
  _globals['_SENDCUSTOMEVENTREQUEST']._serialized_start=387
  _globals['_SENDCUSTOMEVENTREQUEST']._serialized_end=497
  _globals['_SENDCUSTOMEVENTRESPONSE']._serialized_start=499
  _globals['_SENDCUSTOMEVENTRESPONSE']._serialized_end=551
  _globals['_IEVENTPAGINATIONTOKENS']._serialized_start=553
  _globals['_IEVENTPAGINATIONTOKENS']._serialized_end=663
  _globals['_LISTEVENTSREQUEST']._serialized_start=666
  _globals['_LISTEVENTSREQUEST']._serialized_end=802
  _globals['_LISTEVENTSRESPONSE']._serialized_start=805
  _globals['_LISTEVENTSRESPONSE']._serialized_end=995
  _globals['_IEVENT']._serialized_start=998
  _globals['_IEVENT']._serialized_end=1708
  _globals['_IEVENT_CONTEXTENTRY']._serialized_start=1589
  _globals['_IEVENT_CONTEXTENTRY']._serialized_end=1647
  _globals['_IEVENT_METADATAENTRY']._serialized_start=1649
  _globals['_IEVENT_METADATAENTRY']._serialized_end=1708
  _globals['_EVENT']._serialized_start=1711
  _globals['_EVENT']._serialized_end=2474
  _globals['_EVENT_CONTEXTENTRY']._serialized_start=1589
  _globals['_EVENT_CONTEXTENTRY']._serialized_end=1647
  _globals['_EVENT_METADATAENTRY']._serialized_start=1649
  _globals['_EVENT_METADATAENTRY']._serialized_end=1708
  _globals['_ACTOR']._serialized_start=2476
  _globals['_ACTOR']._serialized_end=2551
  _globals['_TARGET']._serialized_start=2553
  _globals['_TARGET']._serialized_end=2630
  _globals['_IEVENTFILTER']._serialized_start=2633
  _globals['_IEVENTFILTER']._serialized_end=3130
  _globals['_IEVENTFILTER_METADATAENTRY']._serialized_start=1649
  _globals['_IEVENTFILTER_METADATAENTRY']._serialized_end=1708
  _globals['_EVENTFILTER']._serialized_start=3133
  _globals['_EVENTFILTER']._serialized_end=3426
  _globals['_SCALEKITEVENT']._serialized_start=3429
  _globals['_SCALEKITEVENT']._serialized_end=3839
  _globals['_EVENTSSERVICE']._serialized_start=4825
  _globals['_EVENTSSERVICE']._serialized_end=5147
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from scalekit.v1.directories import directories_pb2 as scalekit_dot_v1_dot_directories_dot_directories__pb2


class DirectoryServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateDirectory = channel.unary_unary(
                '/scalekit.v1.directories.DirectoryService/CreateDirectory',
                request_serializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.CreateDirectoryRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.CreateDirectoryResponse.FromString,
                )
        self.DeleteDirectory = channel.unary_unary(
                '/scalekit.v1.directories.DirectoryService/DeleteDirectory',
                request_serializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.DeleteDirectoryRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateDirectory = channel.unary_unary(
                '/scalekit.v1.directories.DirectoryService/UpdateDirectory',
                request_serializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.UpdateDirectoryRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.UpdateDirectoryResponse.FromString,
                )
        self.AssignGroupsForDirectory = channel.unary_unary(
                '/scalekit.v1.directories.DirectoryService/AssignGroupsForDirectory',
                request_serializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.AssignGroupsForDirectoryRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.AssignRoles = channel.unary_unary(
                '/scalekit.v1.directories.DirectoryService/AssignRoles',
                request_serializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.AssignRolesRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.AssignRolesResponse.FromString,
                )
        self.UpdateAttributes = channel.unary_unary(
                '/scalekit.v1.directories.DirectoryService/UpdateAttributes',
                request_serializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.UpdateAttributesRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.UpdateAttributesResponse.FromString,
                )
        self.GetDirectory = channel.unary_unary(
                '/scalekit.v1.directories.DirectoryService/GetDirectory',
                request_serializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.GetDirectoryRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.GetDirectoryResponse.FromString,
                )
        self.ListDirectories = channel.unary_unary(
                '/scalekit.v1.directories.DirectoryService/ListDirectories',
                request_serializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.ListDirectoriesRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.ListDirectoriesResponse.FromString,
                )
        self.EnableDirectory = channel.unary_unary(
                '/scalekit.v1.directories.DirectoryService/EnableDirectory',
                request_serializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.ToggleDirectoryRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.ToggleDirectoryResponse.FromString,
                )
        self.DisableDirectory = channel.unary_unary(
                '/scalekit.v1.directories.DirectoryService/DisableDirectory',
                request_serializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.ToggleDirectoryRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.ToggleDirectoryResponse.FromString,
                )
        self.ListDirectoryUsers = channel.unary_unary(
                '/scalekit.v1.directories.DirectoryService/ListDirectoryUsers',
                request_serializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.ListDirectoryUsersRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.ListDirectoryUsersResponse.FromString,
                )
        self.ListDirectoryGroups = channel.unary_unary(
                '/scalekit.v1.directories.DirectoryService/ListDirectoryGroups',
                request_serializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.ListDirectoryGroupsRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.ListDirectoryGroupsResponse.FromString,
                )
        self.ListDirectoryGroupsSummary = channel.unary_unary(
                '/scalekit.v1.directories.DirectoryService/ListDirectoryGroupsSummary',
                request_serializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.ListDirectoryGroupsSummaryRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.ListDirectoryGroupsResponse.FromString,
                )
        self.CreateDirectorySecret = channel.unary_unary(
                '/scalekit.v1.directories.DirectoryService/CreateDirectorySecret',
                request_serializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.CreateDirectorySecretRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.CreateDirectorySecretResponse.FromString,
                )
        self.RegenerateDirectorySecret = channel.unary_unary(
                '/scalekit.v1.directories.DirectoryService/RegenerateDirectorySecret',
                request_serializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.RegenerateDirectorySecretRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.RegenerateDirectorySecretResponse.FromString,
                )
        self.TriggerDirectorySync = channel.unary_unary(
                '/scalekit.v1.directories.DirectoryService/TriggerDirectorySync',
                request_serializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.TriggerDirectorySyncRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )


class DirectoryServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateDirectory(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteDirectory(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDirectory(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AssignGroupsForDirectory(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AssignRoles(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateAttributes(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDirectory(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListDirectories(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EnableDirectory(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DisableDirectory(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListDirectoryUsers(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListDirectoryGroups(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListDirectoryGroupsSummary(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateDirectorySecret(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegenerateDirectorySecret(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TriggerDirectorySync(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DirectoryServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateDirectory': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateDirectory,
                    request_deserializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.CreateDirectoryRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.CreateDirectoryResponse.SerializeToString,
            ),
            'DeleteDirectory': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteDirectory,
                    request_deserializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.DeleteDirectoryRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateDirectory': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateDirectory,
                    request_deserializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.UpdateDirectoryRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.UpdateDirectoryResponse.SerializeToString,
            ),
            'AssignGroupsForDirectory': grpc.unary_unary_rpc_method_handler(
                    servicer.AssignGroupsForDirectory,
                    request_deserializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.AssignGroupsForDirectoryRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'AssignRoles': grpc.unary_unary_rpc_method_handler(
                    servicer.AssignRoles,
                    request_deserializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.AssignRolesRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.AssignRolesResponse.SerializeToString,
            ),
            'UpdateAttributes': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateAttributes,
                    request_deserializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.UpdateAttributesRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.UpdateAttributesResponse.SerializeToString,
            ),
            'GetDirectory': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDirectory,
                    request_deserializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.GetDirectoryRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.GetDirectoryResponse.SerializeToString,
            ),
            'ListDirectories': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDirectories,
                    request_deserializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.ListDirectoriesRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.ListDirectoriesResponse.SerializeToString,
            ),
            'EnableDirectory': grpc.unary_unary_rpc_method_handler(
                    servicer.EnableDirectory,
                    request_deserializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.ToggleDirectoryRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.ToggleDirectoryResponse.SerializeToString,
            ),
            'DisableDirectory': grpc.unary_unary_rpc_method_handler(
                    servicer.DisableDirectory,
                    request_deserializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.ToggleDirectoryRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.ToggleDirectoryResponse.SerializeToString,
            ),
            'ListDirectoryUsers': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDirectoryUsers,
                    request_deserializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.ListDirectoryUsersRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.ListDirectoryUsersResponse.SerializeToString,
            ),
            'ListDirectoryGroups': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDirectoryGroups,
                    request_deserializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.ListDirectoryGroupsRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.ListDirectoryGroupsResponse.SerializeToString,
            ),
            'ListDirectoryGroupsSummary': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDirectoryGroupsSummary,
                    request_deserializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.ListDirectoryGroupsSummaryRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.ListDirectoryGroupsResponse.SerializeToString,
            ),
            'CreateDirectorySecret': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateDirectorySecret,
                    request_deserializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.CreateDirectorySecretRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.CreateDirectorySecretResponse.SerializeToString,
            ),
            'RegenerateDirectorySecret': grpc.unary_unary_rpc_method_handler(
                    servicer.RegenerateDirectorySecret,
                    request_deserializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.RegenerateDirectorySecretRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.RegenerateDirectorySecretResponse.SerializeToString,
            ),
            'TriggerDirectorySync': grpc.unary_unary_rpc_method_handler(
                    servicer.TriggerDirectorySync,
                    request_deserializer=scalekit_dot_v1_dot_directories_dot_directories__pb2.TriggerDirectorySyncRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'scalekit.v1.directories.DirectoryService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DirectoryService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateDirectory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.directories.DirectoryService/CreateDirectory',
            scalekit_dot_v1_dot_directories_dot_directories__pb2.CreateDirectoryRequest.SerializeToString,
            scalekit_dot_v1_dot_directories_dot_directories__pb2.CreateDirectoryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteDirectory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.directories.DirectoryService/DeleteDirectory',
            scalekit_dot_v1_dot_directories_dot_directories__pb2.DeleteDirectoryRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateDirectory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.directories.DirectoryService/UpdateDirectory',
            scalekit_dot_v1_dot_directories_dot_directories__pb2.UpdateDirectoryRequest.SerializeToString,
            scalekit_dot_v1_dot_directories_dot_directories__pb2.UpdateDirectoryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AssignGroupsForDirectory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.directories.DirectoryService/AssignGroupsForDirectory',
            scalekit_dot_v1_dot_directories_dot_directories__pb2.AssignGroupsForDirectoryRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AssignRoles(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.directories.DirectoryService/AssignRoles',
            scalekit_dot_v1_dot_directories_dot_directories__pb2.AssignRolesRequest.SerializeToString,
            scalekit_dot_v1_dot_directories_dot_directories__pb2.AssignRolesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateAttributes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.directories.DirectoryService/UpdateAttributes',
            scalekit_dot_v1_dot_directories_dot_directories__pb2.UpdateAttributesRequest.SerializeToString,
            scalekit_dot_v1_dot_directories_dot_directories__pb2.UpdateAttributesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDirectory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.directories.DirectoryService/GetDirectory',
            scalekit_dot_v1_dot_directories_dot_directories__pb2.GetDirectoryRequest.SerializeToString,
            scalekit_dot_v1_dot_directories_dot_directories__pb2.GetDirectoryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListDirectories(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.directories.DirectoryService/ListDirectories',
            scalekit_dot_v1_dot_directories_dot_directories__pb2.ListDirectoriesRequest.SerializeToString,
            scalekit_dot_v1_dot_directories_dot_directories__pb2.ListDirectoriesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EnableDirectory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.directories.DirectoryService/EnableDirectory',
            scalekit_dot_v1_dot_directories_dot_directories__pb2.ToggleDirectoryRequest.SerializeToString,
            scalekit_dot_v1_dot_directories_dot_directories__pb2.ToggleDirectoryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DisableDirectory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.directories.DirectoryService/DisableDirectory',
            scalekit_dot_v1_dot_directories_dot_directories__pb2.ToggleDirectoryRequest.SerializeToString,
            scalekit_dot_v1_dot_directories_dot_directories__pb2.ToggleDirectoryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListDirectoryUsers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.directories.DirectoryService/ListDirectoryUsers',
            scalekit_dot_v1_dot_directories_dot_directories__pb2.ListDirectoryUsersRequest.SerializeToString,
            scalekit_dot_v1_dot_directories_dot_directories__pb2.ListDirectoryUsersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListDirectoryGroups(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.directories.DirectoryService/ListDirectoryGroups',
            scalekit_dot_v1_dot_directories_dot_directories__pb2.ListDirectoryGroupsRequest.SerializeToString,
            scalekit_dot_v1_dot_directories_dot_directories__pb2.ListDirectoryGroupsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListDirectoryGroupsSummary(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.directories.DirectoryService/ListDirectoryGroupsSummary',
            scalekit_dot_v1_dot_directories_dot_directories__pb2.ListDirectoryGroupsSummaryRequest.SerializeToString,
            scalekit_dot_v1_dot_directories_dot_directories__pb2.ListDirectoryGroupsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateDirectorySecret(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.directories.DirectoryService/CreateDirectorySecret',
            scalekit_dot_v1_dot_directories_dot_directories__pb2.CreateDirectorySecretRequest.SerializeToString,
            scalekit_dot_v1_dot_directories_dot_directories__pb2.CreateDirectorySecretResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RegenerateDirectorySecret(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.directories.DirectoryService/RegenerateDirectorySecret',
            scalekit_dot_v1_dot_directories_dot_directories__pb2.RegenerateDirectorySecretRequest.SerializeToString,
            scalekit_dot_v1_dot_directories_dot_directories__pb2.RegenerateDirectorySecretResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TriggerDirectorySync(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.directories.DirectoryService/TriggerDirectorySync',
            scalekit_dot_v1_dot_directories_dot_directories__pb2.TriggerDirectorySyncRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
